from settings import Test

class TestPostgres(Test):
    """ default profile when running tests """
    def init(self):
        # call parent init to setup default settings
        Test.init(self)
        self.db.url = 'postgresql://postgres:postgres@rcsserver/test'
        #self.db.echo = True
testpgsql = TestPostgres
